@@ -1,6 +1,5 @@
 ##
-# Copyright 2012 Ghent University
-# Copyright 2012 Jens Timmerman
+# Copyright 2009-2013 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -17,17 +16,19 @@
 #
 # EasyBuild is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with EasyBuild. If not, see <http://www.gnu.org/licenses/>.
+# along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
 ##
 """
-EasyBlock for binary applications that need unpacking,
-e.g., binary applications shipped as a .tar.gz file
+EasyBlock for binary applications that need unpacking, e.g., binary applications shipped as a .tar.gz file
+
+@author: Jens Timmerman (Ghent University)
 """
 import os
+import shutil
 
 from easybuild.framework.easyblock import EasyBlock
 from easybuild.easyblocks.generic.binary import Binary
@@ -52,6 +53,10 @@ class PackedBinary(Binary, EasyBlock):
                     # copy files to install dir via Binary
                     self.cfg['start_dir'] = src
                     Binary.install_step(self)
+                elif os.path.isfile(srcpath):
+                    shutil.copy2(srcpath, self.installdir)
+                else:
+                    self.log.error("Path %s is not a file nor a directory?" % srcpath)
         except OSError, err:
             self.log.error("Failed to copy unpacked sources to install directory: %s" % err)
 
